@@ -536,7 +536,7 @@ def parseIBDatetime(s: str) -> Union[dt.date, dt.datetime]:
         t = dt.date(y, m, d)
     elif s.isdigit():
         t = dt.datetime.fromtimestamp(int(s), dt.timezone.utc)
-    elif s.count(' ') >= 2:
+    elif s.count(' ') >= 2 and '  ' not in s:
         # 20221125 10:00:00 Europe/Amsterdam
         s0, s1, s2 = s.split(' ', 2)
         t = dt.datetime.strptime(s0 + s1, '%Y%m%d%H:%M:%S')
